@@ -1,7 +1,7 @@
-// #![deny(missing_docs)]
+#![deny(missing_docs)]
 #![deny(missing_debug_implementations)]
 #![doc = include_str!("../Readme.md")]
 
-pub use crate::traits::{Projective, Projective3D};
+pub use crate::traits::*;
 
 mod traits;
